package com.huake.demo.common;

import org.json.JSONException;
import org.json.JSONObject;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.openqa.selenium.JavascriptExecutor;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;

import java.io.IOException;

public class CaptchaHandler {

    /** 
     * 从 WebElement 获取 Base64 编码的图片数据
     * @param driver WebDriver 实例
     * @param element WebElement 图像元素
     * @return Base64 编码的字符串
     */
    public static String getBase64FromElement(WebDriver driver, WebElement element) {
        JavascriptExecutor jsExecutor = (JavascriptExecutor) driver;
        String script = "var canvas = document.createElement('canvas');" +
                "var ctx = canvas.getContext('2d');" +
                "canvas.width = arguments[0].naturalWidth;" +
                "canvas.height = arguments[0].naturalHeight;" +
                "ctx.drawImage(arguments[0], 0, 0);" +
                "return canvas.toDataURL('image/png').split(',')[1];";
        return (String) jsExecutor.executeScript(script, element);
    }

    /** 
     * 发送验证码图片请求并获取验证码文本
     * @param base64Image Base64 编码的验证码图片
     * @return 验证码文本
     */
    public static String sendCaptchaRequest(String base64Image) {
        try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
            HttpPost post = new HttpPost("http://api.ttshitu.com/predict");
            post.setHeader("Content-Type", "application/json");

            String json = String.format("{\"username\": \"luffy230505\", \"password\": \"XIAOmi123\", \"typeid\": \"1003\", \"image\": \"%s\"}", base64Image);
            post.setEntity(new StringEntity(json));

            try (CloseableHttpResponse response = httpClient.execute(post)) {
                String responseBody = EntityUtils.toString(response.getEntity());
                JSONObject jsonObject = new JSONObject(responseBody);
                if (jsonObject.getBoolean("success")) {
                    return jsonObject.getJSONObject("data").getString("result");
                } else {
                    System.err.println("请求失败: " + jsonObject.getString("message"));
                    return "";
                }
            }
        } catch (IOException | JSONException e) {
            e.printStackTrace();
            return "";
        }
    }
}
